@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2013 Red Hat, Inc.
 # All Rights Reserved.
 #
@@ -42,6 +40,7 @@ def do_port_show(cc, args):
     if args.address:
         port = cc.port.get_by_address(args.port)
     else:
+        utils.check_empty_arg(args.port, '<id>')
         port = cc.port.get(args.port)
     _print_port_show(port)
 
@@ -83,16 +82,21 @@ def do_port_list(cc, args):
 
     if args.address is not None:
         params['address'] = args.address
+
     if args.detail:
         fields = res_fields.PORT_FIELDS
         field_labels = res_fields.PORT_FIELD_LABELS
+        sort_fields = res_fields.PORT_SORT_FIELDS
+        sort_field_labels = res_fields.PORT_SORT_FIELD_LABELS
     else:
         fields = res_fields.PORT_LIST_FIELDS
         field_labels = res_fields.PORT_LIST_FIELD_LABELS
+        sort_fields = fields
+        sort_field_labels = field_labels
 
     params.update(utils.common_params_for_list(args,
-                                               fields,
-                                               field_labels))
+                                               sort_fields,
+                                               sort_field_labels))
 
     port = cc.port.list(**params)
     cliutils.print_list(port, fields,
